# -*- coding: utf-8 -*-
# Filename:  qmmp.py

import dbus,sys
from dbus.mainloop.glib import DBusGMainLoop
from playerBase import Status
from dbusplayer import dbusPlayer

class qmmp(dbusPlayer):
	
	def __init__(self):
		self.process = "qmmp"
		DBusGMainLoop(set_as_default=True)
		bus_names = dbus.SessionBus().list_names()
		self.version = 0
		if "org.qmmp.dbus" in bus_names:
			#Qmmp 2
			dbusPlayer.__init__(self,"qmmp",("org.qmmp.dbus","/Qmmp","org.qmmp.dbus"),("org.qmmp.dbus","/Qmmp","org.freedesktop.DBus.Properties"))
			self.iface[0].connect_to_signal('started',self.songStarted)
			self.iface[0].connect_to_signal('paused',self.paused)
			self.iface[0].connect_to_signal('stopped',self.songEnded)
			self.version = 2
		elif "org.mpris.qmmp" in bus_names:
			#Qmmp 3
			dbusPlayer.__init__(self,"qmmp","org.mpris.qmmp","/Player","org.freedesktop.MediaPlayer")
			self.iface.connect_to_signal("StatusChange", self.statusChanged)
			self.version = 3
		else:
			raise Exception("Player 'qmmp' is not running.")
	
	#TRACK SECTION
	def getTitle(self):
		if self.version == 2:
			return self.iface[1].Get('org.qmmp.dbus','title')
		else:
			return self.iface.GetMetadata()['title']
	
	def getArtist(self):
		if self.version == 2:
			return self.iface[1].Get('org.qmmp.dbus','artist')
		else:
			return self.iface.GetMetadata()['artist']
	
	def getTimePoint(self):
		if self.version == 2:
			time = int(self.iface[1].Get('org.qmmp.dbus','elapsedTime'))*1000
			return self.handleTime(time)
		else:
			return self.iface.PositionGet()
	
	def getMediaFile(self):
		if self.version == 2:
			return self.iface[1].Get('org.qmmp.dbus','path')
		else:
			return self.iface.GetMetadata()['location']
	
	#PLAYER SECTION
	def getStatus(self):
		if self.version == 2:
			if(bool(self.iface[1].Get('org.qmmp.dbus','isPaused'))):
				return Status().Paused
			elif(bool(self.iface[1].Get('org.qmmp.dbus','isStopped'))):
				return Status().Stopped
			else:
				return Status().Playing
		else:
			sys.stdout.write('\n')
			if self.iface.GetMetadata()['time'] == 0:
				return Status().Stopped
			t = self.getTimePoint()
			if t == self.getTimePoint():
				return Status().Paused
			return Status().Playing
		
	def playFunc(self):
		if self.version == 2:
			self.iface[0].play()
		else:
			self.iface.Play()
	
	def pauseFunc(self):
		if self.version == 2:
			self.iface[0].pause()
		else:
			self.iface.Pause()
	
	def stopFunc(self):
		if self.version == 2:
			self.iface[0].stop()
		else:
			self.iface.Stop()
	
	def prevFunc(self):
		if self.version == 2:
			self.iface[0].previous()
		else:
			self.iface.Prev()
	
	def nextFunc(self):
		if self.version == 2:
			self.iface[0].next() 
		else:
			self.iface.Next()
	
	#EVENTS SECTION
	def songStarted(self,*args):
		if self.callback != None:
			self.callback(Status().Playing)
	
	def paused(self,*args):
		if self.callback != None:
			self.callback(Status().Paused)
	
	def songEnded(self,*args):
		if self.callback != None:
			self.callback(Status().Stopped)
	
	def statusChanged(self,args):
		if self.callback != None:
			if args[0] == 0:
				self.callback(Status().Playing)
			elif args[0] == 1:
				self.callback(Status().Paused)
			else:
				self.callback(Status().Stopped)

