# -*- coding: utf-8 -*-
# Filename: preference.py


from PyQt4.QtGui import *
from PyQt4.QtCore import *

from preferenceEngines import preferenceEngines
from preferenceFilter import preferenceFilter
from preferenceGeneral import preferenceGeneral
from preferenceIcontray import preferenceIcontray
from preferenceInterface import preferenceInterface
from preferenceShortcut import preferenceShortcut
from preferencePath import preferencePath
from preferenceMultisearch import preferenceMultisearch
from preferenceLaunchPlayer import preferenceLaunchPlayer

import sys, glob, os

class preference(QDialog):
	
	def __init__(self, parent, configItem):
        	QDialog.__init__(self, parent)
        	self.setWindowTitle(_('Preference'))
        	self.locale = sys.getfilesystemencoding()
        	
        	(minWidth, lineMargin, trayInfoTime, autoEmbed, autoEmbedFromLocal,
		autoEmbedFromNet, noLrc, includeCancel, transparency, rememberOpacity,
		titleBarInfo, rememberShowMode, asTrackName, completeTag, useUslt,
		filterLyrics, saveToMediaPath, searchMediaPath, filterRule, path, enableMultiEngines,
		multiEngines, recursionDepth, saveLrcPath, encoderToWrite, lrcTagType, proxy,
		filterCap, enableTrayIcon, trayIconNotify, shortcutsValue, launchPlayer, playerPath,
		autoLaunch) = configItem
		
		mainWindowLayout = QVBoxLayout(None)

 		layout1=QHBoxLayout(None)       	
		self.itemBox = QListWidget(self)
		self.itemBox.setFixedWidth(140)
		itemList = [_('General'), _('Interface'), _('Paths'), _('Filter'), _('Shortcuts'), _('Icon tray'), _('Launch player'), _('Engine manager'), _('Multi-search')]
		for i in itemList:
			self.itemBox.addItem(i)
		self.itemBox.setCurrentRow(0)
		
		settingTab = QStackedWidget(self)
		self.generalTab = preferenceGeneral()
        	self.interfaceTab = preferenceInterface()
        	self.pathTab = preferencePath()
        	self.filterTab = preferenceFilter()
        	self.shortcutTab = preferenceShortcut(shortcutsValue)
        	self.trayIconTab = preferenceIcontray()
        	self.playerTab = preferenceLaunchPlayer()
        	self.engineTab = preferenceEngines()
        	self.multiSearchTab = preferenceMultisearch()
        	settingTab.addWidget(self.generalTab)
        	settingTab.addWidget(self.interfaceTab)
        	settingTab.addWidget(self.pathTab)
        	settingTab.addWidget(self.filterTab)
        	settingTab.addWidget(self.shortcutTab)
        	settingTab.addWidget(self.trayIconTab)
        	settingTab.addWidget(self.playerTab)
        	settingTab.addWidget(self.engineTab)
        	settingTab.addWidget(self.multiSearchTab)
        	
        	layout1.addWidget(self.itemBox)
		layout1.addWidget(settingTab)

		self.interfaceTab.minWidth.setValue(minWidth)
		self.interfaceTab.marginValue.setValue(lineMargin)
		self.trayIconTab.trayTime.setValue(trayInfoTime/1000)
		if(autoEmbed == 'yes'):
			self.generalTab.autoEmbed.setChecked(True)
		if(autoEmbedFromLocal == 'yes'):
			self.generalTab.autoEmbedFromLocal.setChecked(True)
		if(autoEmbedFromNet == 'yes'):
			self.generalTab.autoEmbedFromNet.setChecked(True)
		if(noLrc == 'normal'):
			self.interfaceTab.groupHide.normal.setChecked(True)
		elif(noLrc == 'hide'):
			self.interfaceTab.groupHide.hide.setChecked(True)
		else:
			self.interfaceTab.groupHide.mini.setChecked(True)
		if(includeCancel == 'yes'):
			self.interfaceTab.groupHide.includeCheckBox.setChecked(True)
		if(transparency == 'yes'):
			self.interfaceTab.enableTransparency.setChecked(True)
		if(rememberOpacity == 'yes'):
			self.interfaceTab.rememberOpacity.setChecked(True)
		if(titleBarInfo == 'yes'):
			self.interfaceTab.autoTitleBar.setChecked(True)
		if(rememberShowMode == 'yes'):
			self.interfaceTab.rememberLastShowMode.setChecked(True)
		if(asTrackName == 'yes'):
			self.generalTab.asTrackName.setChecked(True)
		if(completeTag == 'yes'):
			self.generalTab.completeTagSearch.setChecked(True)
		if(useUslt == 'yes'):
			self.generalTab.lrcInMedia.setChecked(True)
		if(filterLyrics == 'yes'):
			self.filterTab.filterCheckBox.setChecked(True)
		else:
			self.filterTab.filterCheckBox.setChecked(False)
		if(saveToMediaPath == 'yes'):
			self.pathTab.saveToMediaPath.setChecked(True)
		if(searchMediaPath == 'yes'):
			self.pathTab.searchMediaPath.setChecked(True)
		self.filterTab.filterKeyWold.setText(filterRule)
		tmpPathList = map(lambda x:unicode(x, self.locale), path)
		if(enableMultiEngines == 'yes'):
			self.multiSearchTab.multiSearch.setChecked(True)
		for k in glob.glob('./engines/engine_*.py'):
			j = os.path.basename(k)[7:-3]
			self.engineTab.addEngine(j, k)
			if(j not in multiEngines):
				self.multiSearchTab.allEngines.addItem(j)
		for m in multiEngines:
			self.multiSearchTab.userEngines.addItem(m)
		for i in tmpPathList:
			self.pathTab.insertPath(i, recursionDepth[tmpPathList.index(i)])
		self.pathTab.savePath.setText(unicode(saveLrcPath, self.locale))
		index = self.generalTab.strList.index(encoderToWrite)
		self.generalTab.comboBox.setCurrentIndex(index)
		
		index_ = self.generalTab.strTagList.index(lrcTagType)
		self.generalTab.comboBoxType.setCurrentIndex(index_)
		if(proxy):
			self.generalTab.proxy.setText(proxy['http'])
		if(filterCap == 'yes'):
			self.filterTab.filterCap.setChecked(True)
		if(enableTrayIcon == 'yes'):
			self.trayIconTab.enableTray.setChecked(True)
		else:
			self.trayIconTab.enableTray.setChecked(False)
		if(trayIconNotify == 'yes'):
			self.trayIconTab.enableNotify.setChecked(True)
		else:
			self.trayIconTab.trayTime.setEnabled(False)
		if(autoLaunch == 'yes'):
			self.playerTab.rememberPlayer.setEnabled(True)
		self.playerTab.playerList.setCurrentIndex(self.playerTab.supportPlayer.index(launchPlayer))
		self.playerTab.pathBox.setText(unicode(playerPath, 'utf8'))

		buttonBox = QDialogButtonBox(self)
		okButton = QPushButton(QIcon('./icon/ok.png'), _('Ok'))
		cancelButton = QPushButton(QIcon('./icon/cancel.png'), _('Cancel'))
        	buttonBox.addButton(okButton, QDialogButtonBox.AcceptRole)
        	buttonBox.addButton(cancelButton, QDialogButtonBox.RejectRole)
		
		mainWindowLayout.addLayout(layout1)
		mainWindowLayout.addWidget(buttonBox)
		self.setLayout(mainWindowLayout)
		
		self.connect(buttonBox, SIGNAL('accepted()'), self.acceptAction)
        	self.connect(buttonBox, SIGNAL('rejected()'), self, SLOT('reject()'))
        	self.connect(self.itemBox,SIGNAL("currentRowChanged(int)"),settingTab,SLOT("setCurrentIndex(int)"))
        
        def acceptAction(self):
		self.minWidth = self.interfaceTab.minWidth.value()


		self.lineMargin = self.interfaceTab.marginValue.value()

		
		self.trayInfoTime = self.trayIconTab.trayTime.value()*1000

		if(self.interfaceTab.groupHide.normal.isChecked()):
			self.noLrc = 'normal'
		elif(self.interfaceTab.groupHide.hide.isChecked()):
			self.noLrc = 'hide'
		elif(self.interfaceTab.groupHide.mini.isChecked()):
			self.noLrc = 'mini'

		if(self.interfaceTab.enableTransparency.isChecked()):
			self.transparency = 'yes'
		else:
			self.transparency = 'no'

		if(self.interfaceTab.rememberOpacity.isChecked()):
			self.rememberOpacity = 'yes'
		else:
			self.rememberOpacity = 'no'

		if(self.interfaceTab.groupHide.includeCheckBox.isChecked()):
			self.includeCancel = 'yes'
		else:
			self.includeCancel = 'no'

		if(self.generalTab.asTrackName.isChecked()):
			self.asTrackName = 'yes'
		else:
			self.asTrackName='no'

		if(self.generalTab.autoEmbedFromLocal.isChecked()):
			self.autoEmbedFromLocal = 'yes'
		else:
			self.autoEmbedFromLocal = 'no'

		if(self.generalTab.autoEmbedFromNet.isChecked()):
			self.autoEmbedFromNet = 'yes'
		else:
			self.autoEmbedFromNet = 'no'

		if(self.generalTab.autoEmbed.isChecked()):
			self.autoEmbed = 'yes'
		else:
			self.autoEmbed = 'no'

		if(self.generalTab.lrcInMedia.isChecked()):
			self.useUslt = 'yes'
		else:
			self.useUslt = 'no'

		if(self.interfaceTab.autoTitleBar.isChecked()):
			self.titleBarInfo = 'yes'
		else:
			self.titleBarInfo = 'no'

		if(self.interfaceTab.rememberLastShowMode.isChecked()):
			self.rememberShowMode = 'yes'
		else:
			self.rememberShowMode = 'no'

		if(self.generalTab.completeTagSearch.isChecked()):
			self.completeTag = 'yes'
		else:
			self.completeTag = 'no'

		if(self.filterTab.filterCheckBox.isChecked() and not self.filterTab.filterKeyWold.text().isEmpty()):
			self.filterLyrics = 'yes'
		else:
			self.filterLyrics = 'no'

		if(self.filterTab.filterCap.isChecked()):
			self.filterCap = 'yes'
		else:
			self.filterCap = 'no'

		self.filterRule = self.filterTab.filterKeyWold.text()

		if(self.pathTab.saveToMediaPath.isChecked()):
			self.saveToMediaPath = 'yes'
		else:
			self.saveToMediaPath = 'no'

		if(self.pathTab.searchMediaPath.isChecked()):
			self.searchMediaPath = 'yes'
		else:
			self.searchMediaPath = 'no'

		if(self.trayIconTab.enableTray.isChecked()):
			self.enableTrayIcon = 'yes'
		else:
			self.enableTrayIcon = 'no'

		if(self.multiSearchTab.multiSearch.isChecked()):
			self.enableMultiEngines = 'yes'
		else:
			self.enableMultiEngines = 'no'

		self.tmpMultiEngines = ''
		for i in range(self.multiSearchTab.userEngines.count()):
			self.tmpMultiEngines += '%s,' %self.multiSearchTab.userEngines.item(i).text()
			self.multiEngines = self.tmpMultiEngines.split(',')[0:-1]

		if(self.trayIconTab.enableNotify.isChecked()):
			self.trayIconNotify = 'yes'
		else:
			self.trayIconNotify = 'no'

		self.s1 = ''
		self.s3 = ''
		for j in range(0, self.pathTab.rowNumber):
			self.s1 += '%s,' %self.pathTab.table.item(j, 0).text().toUtf8()
			self.s3 += '%s,' %self.pathTab.table.cellWidget(j, 1).currentText()
		self.s2 = self.pathTab.savePath.text().toUtf8()
		self.path = map(lambda x: unicode(x, 'utf8').encode(self.locale), self.s1.split(',')[0:-1])
		self.recursionDepth = self.s3.split(',')[0:-1]
		self.saveLrcPath = unicode(self.s2, 'utf8').encode(self.locale)

		self.encoderToWrite = str(self.generalTab.comboBox.currentText().toUtf8())

		self.lrcTagType = self.generalTab.comboBoxType.currentText().toUtf8()

		self.pp = self.generalTab.proxy.text()
		if(self.pp.isEmpty()):
			self.proxy = None
		else:
			self.proxy = {'http':str(self.pp)}
		
		self.shortcutsValue = self.shortcutTab.shortcutsValue
		
		if(self.playerTab.rememberPlayer.isChecked()):
			self.autoLaunch = 'yes'
		else:
			self.autoLaunch = 'no'
		
		self.playerPath = self.playerTab.pathBox.text().toUtf8()
		self.launchPlayer = self.playerTab.playerList.currentText().toUtf8()

		self.accept()


# test code
def main(args):
	app = QApplication(args)
	win = preference()
	win.show()
	sys.exit(app.exec_())

if(__name__  ==  "__main__"):
	main(sys.argv)